# Prevalent Wind Profile Shapes and Corresponding Magnitude Probability Distributions for an On- and Offshore Location in the Netherlands

This dataset contains the onshore and offshore wind profile shapes identified in the doctoral thesis "Power to the Airborne Wind Energy Performance Model" [[1](#Schelbergen2024)]. These wind profile shapes are published so that other researchers can utilise them to quantify the effect of wind profile variability on the performance of AWE systems of various types and sizes different from those used in the thesis. Using the same wind data allows for fair cross-comparison and may serve as a means of validation. Ultimately, these wind profile shapes may help to promote the standardisation of wind conditions for rating AWE systems in terms of power production.

The thesis uses two approaches to identify dominant wind profile shapes described in chapters 4 and 8. Both approaches apply similar data processing steps to the hourly wind profiles obtained from downscaled reanalysis data. As a first preprocessing step, every hourly wind profile is decomposed into a shape function and a magnitude component. Next, the wind profiles are manually clustered by shape, and each cluster's mean wind profile shape is determined. The thesis presents the resulting dominant wind profile shapes of two locations in the Netherlands: the onshore site of the met mast Cabauw (mmca) and the offshore site of the met mast IJmuiden (mmij).  

Chapter 4 "Establishing the wind profile climatology" identifies two-component wind profile shapes such that the change in wind direction with height is also described. The wind profiles are normalised with respect to the wind speed at a height of 100 meters. The clustering is done using the k-means clustering algorithm. This chapter is based on the paper "Clustering Wind Profile Shapes to Estimate Airborne Wind Energy Production" [[2](#Schelbergen2020)]. Due to an error in the code, the frequency distributions presented in this paper are incorrect. This error has been corrected in the frequency distributions included in this repository.

Chapter 8 "Optimising the flight operation for long-term performance assessment" only studies wind speed profiles and does not consider wind direction profiles. The single-component wind profile shapes can be compared directly to the logarithmic wind profile. The wind profiles are normalised with respect to the wind speed at a height of 200 meters, which is expected to be a better predictor of the power output than the wind speed at 100 meters. The cluster boundaries are allocated manually in the space defined by the first two principal components. This approach provides more control over the clusters and is expected to reduce sensitivity to outliers and unevenly sized clusters.

The data used in this study is the Dutch Offshore Wind Atlas (DOWA) data produced by the Royal Netherlands Meteorological Institute [[3](#DOWA)]. DOWA is produced by downscaling ERA5 data to a finer-resolution surface grid using their mesoscale weather model HARMONIE-AROME. The downscaled reanalysis is performed for 10 years from 2008 until 2017. The DOWA data includes hourly values of the wind speed and direction on a 217 x 234 grid with 2.5 km spacing and 17 heights between 10 and 600 m. The wind data of the two investigated sites are obtained from the nearest grid points.

## Content

In this repository, the following data are provided in csv-files for the mmca and mmij locations:
 - cluster_shapes_ch4_[loc].csv: Eight dominant wind profile shapes normalised with respect to the wind velocity at 100 m height.
 - cluster_frequency_ch4_[loc].csv: The corresponding wind speed distributions as a function of the wind speed at 200 m height.


 - cluster_shapes_ch8_[loc].csv: Six dominant wind profile shapes normalised with respect to the wind speed at 200 m height. Additionally, the neutral logarithmic wind profile is included.
 - cluster_frequency_ch8_[loc].csv: The corresponding wind speed distributions as a function of the wind speed at 200 m height.

Moreover, Python scripts are provided to plot the data.

## References

<a name="Schelbergen2024">[1]</a> Mark Schelbergen: "Power to the Airborne Wind Energy Performance Model: Estimating Long-term Energy Production with an Emphasis on Pumping Flexible-kite Systems". Delft University of Technology, 2024. https://doi.org/10.4233/uuid:353d390a-9b79-44f1-9847-136a6b880e12

<a name="Schelbergen2020">[2]</a> Mark Schelbergen, Peter Kalverla, Roland Schmehl and Simon Watson: "Clustering Wind Profile Shapes to Estimate Airborne Wind Energy Production". Wind Energy Science, 2020; 5:3, 1097-1120. https://doi.org/10.5194/wes-5-1097-2020

<a name="DOWA">[3]</a> I.L. Wijnant et al.: "The Dutch Offshore Wind Atlas (DOWA): description of the dataset". KNMI, 2019. https://www.knmi.nl/research/publications/the-dutch-offshore-wind-atlas-dowa-description-of-the-dataset-25162382-5495-478f-903f-d0a7aa4004e5

## Author

Mark Schelbergen¹ (email: m.schelbergen@hhs.nl)

¹ Faculty of Aerospace Engineering, Delft University of Technology, Kluyverweg 1, 2629 HS Delft, The Netherlands