import pandas as pd
import matplotlib.pyplot as plt


def plot_distributions(ax, bin_frequencies, bin_limits, labels):
    ll = bin_limits[0]
    ul = bin_limits[1]
    for i, freqs in enumerate(bin_frequencies):
        lbl = labels[i]

        if i == 0:
            clr = 'k'
            ls = ':'
        else:
            clr = f'C{i-1}'
            ls = '-'
        ax.bar((ll + ul) / 2, freqs, alpha=.1, width=.5, color=clr)
        ax.plot((ll + ul) / 2, freqs, ls, color=clr, label=lbl)
    ax.grid()
    ax.set_xlim([0, df_mmca.iloc[:, 1].max()])
    ax.set_xlabel(r'$v_{\rm w,200m}$ [m/s]')


ax = plt.subplots(1, 2, sharex=True, sharey=True, figsize=(7, 3.5))[1]
ax[0].set_title('Onshore')
ax[1].set_title('Offshore')
plt.subplots_adjust(top=0.72, bottom=0.165, left=0.1, right=0.985, wspace=0.1)

df_mmca = pd.read_csv('cluster_frequency_ch8_mmca.csv', header=1)
plot_distributions(ax[0], df_mmca.iloc[:, 2:9].values.T, (df_mmca.iloc[:, 0], df_mmca.iloc[:, 1]), df_mmca.columns[2:])

df_mmij = pd.read_csv('cluster_frequency_ch8_mmij.csv', header=1)
plot_distributions(ax[1], df_mmij.iloc[:, 2:9].values.T, (df_mmij.iloc[:, 0], df_mmij.iloc[:, 1]), df_mmij.columns[2:])

ax[0].set_ylabel('Bin frequency [%]')
ax[1].legend(bbox_to_anchor=(-.85, 1.15, 1.6, 0.2), loc="lower left", mode="expand", borderaxespad=0, ncol=3)

plt.show()
