import pandas as pd
import numpy as np
import matplotlib.pyplot as plt

x_lim_profiles = [-0.8, 1.7]


def plot_wind_profile_shapes(altitudes, wind_prl, wind_prp, wind_mag=None, n_rows=2):
    n_profiles = len(wind_prl)
    x_label0 = r"$\tilde{v}$ [-]"
    x_label1 = r"$\tilde{v}_{\parallel}$ [-]"
    y_label1 = r"$\tilde{v}_{\bot}$ [-]"

    n_cols = int(np.ceil(n_profiles/n_rows))
    figsize = (n_cols*2+.8, n_rows*4.8+.4)
    height_ratios = np.ones(2*n_rows)
    for j in range(n_rows):
        height_ratios[2*j] = 1.8
    fig, ax = plt.subplots(2*n_rows, n_cols, figsize=figsize, sharex=True, gridspec_kw={'height_ratios': height_ratios})
    wspace = 0.2
    plt.subplots_adjust(top=0.955, bottom=0.05, left=0.08, right=0.98, hspace=0.2, wspace=wspace)

    for j in range(n_rows):
        ax[0+2*j, 0].set_xlim(x_lim_profiles)
        ax[0+2*j, 0].set_ylabel("Height [m]")
        ax[1+2*j, 0].set_ylabel(y_label1)

    for i in range(n_profiles):
        prl, prp = wind_prl[i], wind_prp[i]
        k = i%n_cols
        j = i//n_cols*2
        ax[j, k].plot(prl, altitudes, label="Parallel", color='#ff7f0e')
        ax[j, k].plot(prp, altitudes, label="Perpendicular", color='#1f77b4')
        ax[0, 0].get_shared_y_axes().join(ax[0, 0], ax[j, k])

        wind_dir = []
        for v_prl, v_prp in zip(wind_prl[i, :], wind_prp[i, :]):
            wind_dir.append(np.arctan2(v_prp, v_prl))

        if wind_mag is not None:
            ax[j, k].plot(wind_mag[i], altitudes, '--', label='Magnitude', color='#2ca02c')

        txt = '${}$'.format(i+1)
        ax[j, k].plot(0.1, 0.1, 'o', mfc="white", alpha=1, ms=14, mec='k', transform=ax[j, k].transAxes)
        ax[j, k].plot(0.1, 0.1, marker=txt, alpha=1, ms=7, mec='k', transform=ax[j, k].transAxes)

        ax[j, k].grid(True)
        ax[j, k].set_xlabel(x_label0)

        ax[j+1, k].plot(prl, prp, color='#7f7f7f')
        ax[j+1, k].plot([0, prl[0]], [0, prp[0]], ':', color='#7f7f7f')
        ax[j+1, k].grid(True)
        ax[j+1, k].axes.set_aspect('equal')
        ax[j+1, k].set_ylim([-.8, .8])
        ax[j+1, k].set_xlabel(x_label1)

        if k > 0:
            ax[j, k].set_yticklabels([])
            ax[j+1, k].set_yticklabels([])

    ax[0, 0].legend(bbox_to_anchor=(1.25+wspace, 1.05, 1.5+wspace*1, 0.2), loc="lower left", mode="expand",
                    borderaxespad=0, ncol=4)
    ax[0, 0].set_ylim([0, 600])


df_mmca = pd.read_csv('cluster_shapes_ch4_mmca.csv')
plot_wind_profile_shapes(df_mmca['Heights'], df_mmca.iloc[:, 1::2].values.T, df_mmca.iloc[:, 2::2].values.T)
df_mmca = pd.read_csv('cluster_shapes_ch4_mmij.csv')
plot_wind_profile_shapes(df_mmca['Heights'], df_mmca.iloc[:, 1::2].values.T, df_mmca.iloc[:, 2::2].values.T)

plt.show()
