import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from scipy.interpolate import Akima1DInterpolator


def plot_wind_profile_shapes(ax, profiles, altitudes, labels):
    plot_altitudes = np.linspace(0, altitudes[-1], 100)
    for i, v in enumerate(profiles):
        lbl = labels[i]

        f_interp = Akima1DInterpolator(np.insert(altitudes, 0, 0), np.insert(v, 0, 0))
        if i == 0:
            plot_args = ('k:',)
        else:
            plot_args = ()
        ax.plot(f_interp(plot_altitudes), plot_altitudes, *plot_args, label=lbl)
    ax.set_ylim([0, 600])
    ax.set_xlabel(r"$\tilde{v}_{\rm w}$ [-]")
    ax.grid()


ax = plt.subplots(1, 2, sharex=True, sharey=True, figsize=(5, 4))[1]
ax[0].set_title('Onshore')
ax[1].set_title('Offshore')
plt.subplots_adjust(top=0.735, bottom=0.13, left=0.14, right=0.99, wspace=.15)

df_mmca = pd.read_csv('cluster_shapes_ch8_mmca.csv')
plot_wind_profile_shapes(ax[0], df_mmca.iloc[:, 1:8].values.T, df_mmca.iloc[:, 0].values, df_mmca.columns[1:])
df_mmij = pd.read_csv('cluster_shapes_ch8_mmij.csv')
plot_wind_profile_shapes(ax[1], df_mmij.iloc[:, 1:8].values.T, df_mmij.iloc[:, 0].values, df_mmij.columns[1:])


ax[0].set_ylabel('Height [m]')
ax[1].legend(bbox_to_anchor=(-1.15, 1.15, 2.15, 0.2), loc="lower left", mode="expand", borderaxespad=0, ncol=3)

plt.show()
